import React, { useState, useCallback, useEffect } from 'react';//For importing the React library
import ReactDOM from 'react-dom';//Importing the react dom
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';//for supporting file formats from D3.js
//Below is the url of the dataset which I created for generating the bar chart
const csvUrl =
  'https://gist.githubusercontent.com/Snigdha6698/b2d7e61cddce42ce0a5188643de3f3ba/raw/7da9ca004f597e676eb9a595e3662cf119af1bfa/ICE6(7).csv'
const width = 960;// Width for the graph
const height = 500;// height for the graph
const margin = { top: 20, right: 20, bottom: 50, left: 200 };// Margin for the graph



const App = () => {
  const [data, setData] = useState(null);//

  useEffect(() => {
    const row = d => {
      d.Population = +d['2019'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 10));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;//Height of the Bar chart
  const innerWidth = width - margin.left - margin.right;//width of the Bar chart
//Below code gives the information for yaxis
  const yScale = scaleBand()
    .domain(data.map(d => d.State))
    .range([0, innerHeight]);
//Below code gives the information for xaxis
  const xScale = scaleLinear()
    .domain([0, max(data, d => d.Population)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>//width and height of the graph
      <g transform={`translate(${margin.left},${margin.top})`}>// for margins
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="green" />// for giving the lines in the graph
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}//stroke value
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.State}//for creating the bar for number of states
            x={0}
            y={yScale(d.State)}//for creating the bar for number of states
            width={xScale(d.Population)}
            height={yScale.bandwidth()}
            fill='skyblue'
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);